__version__ = "0.1.3"
__git_commiter_name__ = "Guy Rozendorn"
__git_commiter_email__ = "guy@rzn.co.il"
__git_branch__ = '(detached from v0.1.3)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'a403688e2c221aec2cfd56513763ac037adcf718'
__git_head_subject__ = 'Finished release v0.1.3.'
__git_head_message__ = '* release/v0.1.3:\n  buildout.cfg: adding setuptools to requirements\n  buildout.cfg: remove distribute from requirements\n  update dependencies'
__git_dirty_diff__ = ''